@@ -11,7 +11,7 @@
 /*                                                             */
 /***************************************************************/
 
-/* $Id: custom.h,v 1.31 2005/04/12 00:59:41 dfs Exp $ */
+/* $Id: custom.h,v 1.34 2005/10/16 14:48:02 dfs Exp $ */
 
 /*---------------------------------------------------------------------*/
 /* LAT_DEG, LAT_MIN and LAT_SEC: Latitude of your location             */
@@ -175,21 +175,6 @@
 /*---------------------------------------------------------------------*/
 #define IF_NEST (4*sizeof(unsigned int))
 
-/*---------------------------------------------------------------------*/
-/* Do we handle queued reminders?                                      */
-/*---------------------------------------------------------------------*/
-#if defined(UNIX) || defined(__OS2__)
-#define HAVE_QUEUED 1
-#endif
-
-/*---------------------------------------------------------------------*/
-/* Does our C compiler have prototypes?  Override this test if you     */
-/* are using a non-ANSI compiler that nevertheless has prototypes.     */
-/*---------------------------------------------------------------------*/
-#if defined(__STDC__) || defined(__TURBOC__) || defined(__BORLANDC__)
-#define HAVE_PROTOS 1
-#endif
-
 /*---------------------------------------------------------------------*/
 /* How many attempts to resolve a weird date spec?                     */
 /*---------------------------------------------------------------------*/
@@ -226,9 +211,6 @@
 
 #define PASSTHRU_LEN 24
 
-#define PUBLIC
-#define PRIVATE static
-
 #define PSBEGIN "# rem2ps begin"
 #define PSEND   "# rem2ps end"
 
