@@ -13,19 +13,13 @@
 /***************************************************************/
 
 #include "config.h"
-static char const RCSID[] = "$Id: dorem.c,v 1.10 2005/04/12 01:49:45 dfs Exp $";
+static char const RCSID[] = "$Id: dorem.c,v 1.14 2005/11/20 01:26:59 dfs Exp $";
 
 #include <stdio.h>
 #include <ctype.h>
 #include <string.h>
 
-#ifdef HAVE_STDLIB_H
 #include <stdlib.h>
-#endif
-
-#ifdef HAVE_MALLOC_H
-#include <malloc.h>
-#endif
 
 #include "globals.h"
 #include "err.h"
@@ -33,20 +27,16 @@ static char const RCSID[] = "$Id: dorem.c,v 1.10 2005/04/12 01:49:45 dfs Exp $";
 #include "protos.h"
 #include "expr.h"
 
-/* Define the shell characters to escape */
-static char const EscapeMe[] =
-#ifdef QDOS
-"\"'!$%^&*()|<>[]{}\x9F~;?\\";
-#else
-"\"'!$%^&*()|<>[]{}`~;?\\";
-#endif
+/* Define the shell characters not to escape */
+static char const DontEscapeMe[] =
+"1234567890_-=+abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ@.,";
 
-PRIVATE int ParseTimeTrig ARGS ((ParsePtr s, TimeTrig *tim));
-PRIVATE int ParseLocalOmit ARGS ((ParsePtr s, Trigger *t));
-PRIVATE int ParseScanFrom ARGS ((ParsePtr s, Trigger *t));
-PRIVATE int ParsePriority ARGS ((ParsePtr s, Trigger *t));
-PRIVATE int ParseUntil ARGS ((ParsePtr s, Trigger *t));
-PRIVATE int ShouldTriggerBasedOnWarn ARGS ((Trigger *t, int jul));
+static int ParseTimeTrig (ParsePtr s, TimeTrig *tim);
+static int ParseLocalOmit (ParsePtr s, Trigger *t);
+static int ParseScanFrom (ParsePtr s, Trigger *t);
+static int ParsePriority (ParsePtr s, Trigger *t);
+static int ParseUntil (ParsePtr s, Trigger *t);
+static int ShouldTriggerBasedOnWarn (Trigger *t, int jul);
 
 /***************************************************************/
 /*                                                             */
@@ -55,12 +45,7 @@ PRIVATE int ShouldTriggerBasedOnWarn ARGS ((Trigger *t, int jul));
 /*  Do the REM command.                                        */
 /*                                                             */
 /***************************************************************/
-#ifdef HAVE_PROTOS
-PUBLIC int DoRem(ParsePtr p)
-#else
-int DoRem(p)
-ParsePtr p;
-#endif
+int DoRem(ParsePtr p)
 {
 
     Trigger trig;
@@ -111,7 +96,6 @@ ParsePtr p;
     }
 
 /* Queue the reminder, if necessary */
-#ifdef HAVE_QUEUED
     if (jul == JulianToday &&
 	!(!IgnoreOnce &&
 	  trig.once != NO_ONCE &&
@@ -119,15 +103,9 @@ ParsePtr p;
 	QueueReminder(p, &trig, &tim, trig.sched);
 /* If we're in daemon mode, do nothing over here */
     if (Daemon) return OK;
-#endif
-
 
     if (ShouldTriggerReminder(&trig, &tim, jul)) {
-#ifdef OS2_POPUP
-	if ( (r=TriggerReminder(p, &trig, &tim, jul, 0)) )
-#else
-	    if ( (r=TriggerReminder(p, &trig, &tim, jul)) )
-#endif
+	if ( (r=TriggerReminder(p, &trig, &tim, jul)) )
 	    {
 		return r;
 	    }
@@ -144,14 +122,7 @@ ParsePtr p;
 /*  trigger structure.                                         */
 /*                                                             */
 /***************************************************************/
-#ifdef HAVE_PROTOS
-PUBLIC int ParseRem(ParsePtr s, Trigger *trig, TimeTrig *tim)
-#else
-    int ParseRem(s, trig, tim)
-    ParsePtr s;
-    Trigger *trig;
-    TimeTrig *tim;
-#endif
+int ParseRem(ParsePtr s, Trigger *trig, TimeTrig *tim)
 {
     register int r;
     DynamicBuffer buf;
@@ -314,6 +285,7 @@ PUBLIC int ParseRem(ParsePtr s, Trigger *trig, TimeTrig *tim)
 	    DBufFree(&buf);
 	    switch(tok.type) {
 	    case T_Time:
+	    case T_LongTime:
 		tim->duration = tok.val;
 		break;
 	    default:
@@ -328,6 +300,11 @@ PUBLIC int ParseRem(ParsePtr s, Trigger *trig, TimeTrig *tim)
 	    DBufFree(&buf);
 	    break;
 
+	case T_LongTime:
+	    DBufFree(&buf);
+	    return E_BAD_TIME;
+	    break;
+
 	default:
 	    PushToken(DBufValue(&buf), s);
 	    DBufFree(&buf);
@@ -344,13 +321,7 @@ PUBLIC int ParseRem(ParsePtr s, Trigger *trig, TimeTrig *tim)
 /*  ParseTimeTrig - parse the AT part of a timed reminder      */
 /*                                                             */
 /***************************************************************/
-#ifdef HAVE_PROTOS
-PRIVATE int ParseTimeTrig(ParsePtr s, TimeTrig *tim)
-#else
-    static int ParseTimeTrig(s, tim)
-    ParsePtr s;
-    TimeTrig *tim;
-#endif
+static int ParseTimeTrig(ParsePtr s, TimeTrig *tim)
 {
     Token tok;
     int r;
@@ -396,13 +367,7 @@ PRIVATE int ParseTimeTrig(ParsePtr s, TimeTrig *tim)
 /*  reminder.                                                  */
 /*                                                             */
 /***************************************************************/
-#ifdef HAVE_PROTOS
-PRIVATE int ParseLocalOmit(ParsePtr s, Trigger *t)
-#else
-    static int ParseLocalOmit(s, t)
-    ParsePtr s;
-    Trigger *t;
-#endif
+static int ParseLocalOmit(ParsePtr s, Trigger *t)
 {
     Token tok;
     int r;
@@ -432,13 +397,7 @@ PRIVATE int ParseLocalOmit(ParsePtr s, Trigger *t)
 /*  ParseUntil - parse the UNTIL portion of a reminder         */
 /*                                                             */
 /***************************************************************/
-#ifdef HAVE_PROTOS
-PRIVATE int ParseUntil(ParsePtr s, Trigger *t)
-#else
-    static int ParseUntil(s, t)
-    ParsePtr s;
-    Trigger *t;
-#endif
+static int ParseUntil(ParsePtr s, Trigger *t)
 {
     int y = NO_YR,
 	m = NO_MON,
@@ -506,13 +465,7 @@ PRIVATE int ParseUntil(ParsePtr s, Trigger *t)
 /*  ParseScanFrom - parse the SCANFROM portion of a reminder   */
 /*                                                             */
 /***************************************************************/
-#ifdef HAVE_PROTOS
-PRIVATE int ParseScanFrom(ParsePtr s, Trigger *t)
-#else
-    static int ParseScanFrom(s, t)
-    ParsePtr s;
-    Trigger *t;
-#endif
+static int ParseScanFrom(ParsePtr s, Trigger *t)
 {
     int y = NO_YR,
 	m = NO_MON,
@@ -581,37 +534,17 @@ PRIVATE int ParseScanFrom(ParsePtr s, Trigger *t)
 /*  Trigger the reminder if it's a RUN or MSG type.            */
 /*                                                             */
 /***************************************************************/
-#ifdef HAVE_PROTOS
-#ifdef OS2_POPUP
-PUBLIC int TriggerReminder(ParsePtr p, Trigger *t, TimeTrig *tim, int jul,
-			   int AsPopUp)
-#else /* ! OS2_POPUP */
-    PUBLIC int TriggerReminder(ParsePtr p, Trigger *t, TimeTrig *tim, int jul)
-#endif /* OS2_POPUP */
-#else /* ! HAVE_PROTOS */
-#ifdef OS2_POPUP
-    int TriggerReminder(p, t, tim, jul, AsPopUp)
-    ParsePtr p;
-    Trigger *t;
-    TimeTrig *tim;
-    int jul;
-    int AsPopUp;
-#else /* ! OS2_POPUP */
-    int TriggerReminder(p, t, tim, jul)
-    ParsePtr p;
-    Trigger *t;
-    TimeTrig *tim;
-    int jul;
-#endif /* OS2_POPUP */
-#endif /* HAVE_PROTOS */
+    int TriggerReminder(ParsePtr p, Trigger *t, TimeTrig *tim, int jul)
 {
     int r, y, m, d;
     char PrioExpr[25];
-    DynamicBuffer buf;
+    char tmpBuf[64];
+    DynamicBuffer buf, calRow;
     char *s;
     Value v;
 
     DBufInit(&buf);
+    DBufInit(&calRow);
     if (t->typ == RUN_TYPE && RunDisabled) return E_RUN_DISABLED;
     if (t->typ == PASSTHRU_TYPE ||
 	t->typ == CAL_TYPE ||
@@ -624,14 +557,7 @@ PUBLIC int TriggerReminder(ParsePtr p, Trigger *t, TimeTrig *tim, int jul,
 	if (!DoSubstFromString(DBufValue(&Banner), &buf,
 			       JulianToday, NO_TIME) &&
 	    DBufLen(&buf)) {
-#ifdef OS2_POPUP
-	    if (AsPopUp)
-		PutlPopUp(DBufValue(&buf));
-	    else
-		printf("%s\n", DBufValue(&buf));
-#else
 	printf("%s\n", DBufValue(&buf));
-#endif
 	}
 	DBufFree(&buf);
     }
@@ -645,25 +571,54 @@ PUBLIC int TriggerReminder(ParsePtr p, Trigger *t, TimeTrig *tim, int jul,
 	    return OK;
 	}
 	FromJulian(jul, &y, &m, &d);
-#ifdef OS2_POPUP
-	if (AsPopUp) {
-	    char tmpBuf[64];
-	    sprintf(tmpBuf, "%04d%c%02d%c%02d %s", y, DATESEP, m+1, DATESEP, d,
-		    SimpleTime(tim->ttime));
-	    StartPopUp();
-	    PutsPopUp(tmpBuf);
-	    PutlPopUp(DBufValue(&buf));
-	}
-	else
-	    printf("%04d%c%02d%c%02d %s%s\n", y, DATESEP, m+1, DATESEP, d,
-		   SimpleTime(tim->ttime),
-		   DBufValue(&buf));
-#else
-	printf("%04d%c%02d%c%02d %s%s\n", y, DATESEP, m+1, DATESEP, d,
-	       SimpleTime(tim->ttime),
-	       DBufValue(&buf));
-#endif
+ 	sprintf(tmpBuf, "%04d%c%02d%c%02d ", y, DATESEP, m+1, DATESEP, d);
+ 	if (DBufPuts(&calRow, tmpBuf) != OK) {
+ 	    DBufFree(&calRow);
+ 	    return E_NO_MEM;
+ 	}
+ 	/* If DoSimpleCalendar==1, output *all* simple calendar fields */
+ 	if (DoSimpleCalendar) {
+ 	    /* ignore passthru field when in NextMode */
+ 	    if (DBufPuts(&calRow, "* ") != OK) {
+ 		DBufFree(&calRow);
+ 		return E_NO_MEM;
+ 	    }
+ 	    if (t->tag[0]) {
+ 		sprintf(tmpBuf, "%s ", t->tag);
+ 	    } else {
+ 		sprintf(tmpBuf, "* ");
+ 	    }
+ 	    if (DBufPuts(&calRow, tmpBuf) != OK) {
+ 		DBufFree(&calRow);
+ 		return E_NO_MEM;
+ 	    }
+ 	    if (tim->duration != NO_TIME) {
+ 		sprintf(tmpBuf, "%d ", tim->duration);
+ 	    } else {
+ 		sprintf(tmpBuf, "* ");
+ 	    }
+ 	    if (DBufPuts(&calRow, tmpBuf) != OK) {
+ 		DBufFree(&calRow);
+ 		return E_NO_MEM;
+ 	    }
+ 	    if (tim->ttime != NO_TIME) {
+ 		sprintf(tmpBuf, "%d ", tim->ttime);
+ 	    } else {
+ 		sprintf(tmpBuf, "* ");
+ 	    }
+ 	    if (DBufPuts(&calRow, tmpBuf) != OK) {
+ 		DBufFree(&calRow);
+ 		return E_NO_MEM;
+ 	    }
+ 	}
+ 	if (DBufPuts(&calRow, SimpleTime(tim->ttime)) != OK) {
+ 	    DBufFree(&calRow);
+ 	    return E_NO_MEM;
+ 	}
+
+ 	printf("%s%s\n", DBufValue(&calRow), DBufValue(&buf));
 	DBufFree(&buf);
+	DBufFree(&calRow);
 	return OK;
     }
 
@@ -723,29 +678,12 @@ PUBLIC int TriggerReminder(ParsePtr p, Trigger *t, TimeTrig *tim, int jul,
 	if (MsgCommand) {
 	    DoMsgCommand(MsgCommand, DBufValue(&buf));
 	} else {
-#ifdef OS2_POPUP
-	    if (AsPopUp)
-		PutlPopUp(DBufValue(&buf));
-	    else
-		printf("%s", DBufValue(&buf));
-#else
 	    printf("%s", DBufValue(&buf));
-#endif
 	}
 	break;
 
     case MSF_TYPE:
-#ifdef OS2_POPUP
-	if (AsPopUp) {
-	    StartPopUp();
-	    FillParagraph(DBufValue(&buf), 1);
-	    EndPopUp();
-	} else {
-	    FillParagraph(DBufValue(&buf), 0);
-	}
-#else
 	FillParagraph(DBufValue(&buf));
-#endif
 	break;
 
     case RUN_TYPE:
@@ -771,32 +709,19 @@ PUBLIC int TriggerReminder(ParsePtr p, Trigger *t, TimeTrig *tim, int jul,
 /*  triggered.                                                 */
 /*                                                             */
 /***************************************************************/
-#ifdef __TURBOC__
-#pragma argsused
-#endif
-#ifdef HAVE_PROTOS
-PUBLIC int ShouldTriggerReminder(Trigger *t, TimeTrig *tim, int jul)
-#else
-    int ShouldTriggerReminder(t, tim, jul)
-    Trigger *t;
-    TimeTrig *tim;
-    int jul;
-#endif
+int ShouldTriggerReminder(Trigger *t, TimeTrig *tim, int jul)
 {
     int r;
 
     /* Handle the ONCE modifier in the reminder. */
     if (!IgnoreOnce && t->once !=NO_ONCE && FileAccessDate == JulianToday)
 	return 0;
-   
+
     if (jul < JulianToday) return 0;
 
     /* Don't trigger timed reminders if DontIssueAts is true, and if the
        reminder is for today */
-
-#ifdef HAVE_QUEUED
     if (jul == JulianToday && DontIssueAts && tim->ttime != NO_TIME) return 0;
-#endif
 
     /* Don't trigger "old" timed reminders */
 /*** REMOVED...
@@ -837,17 +762,7 @@ PUBLIC int ShouldTriggerReminder(Trigger *t, TimeTrig *tim, int jul)
 /*  Do the "satisfying..." remind calculation.                 */
 /*                                                             */
 /***************************************************************/
-#ifdef __TURBOC__
-#pragma argsused
-#endif
-#ifdef HAVE_PROTOS
-PUBLIC int DoSatRemind(Trigger *trig, TimeTrig *tim, ParsePtr p)
-#else
-    int DoSatRemind(trig, tim, p)
-    Trigger *trig;
-    TimeTrig *tim;
-    ParsePtr p;
-#endif
+int DoSatRemind(Trigger *trig, TimeTrig *tim, ParsePtr p)
 {
     int iter, jul, r;
     Value v;
@@ -881,13 +796,7 @@ PUBLIC int DoSatRemind(Trigger *trig, TimeTrig *tim, ParsePtr p)
 /*  ParsePriority - parse the PRIORITY portion of a reminder   */
 /*                                                             */
 /***************************************************************/
-#ifdef HAVE_PROTOS
-PRIVATE int ParsePriority(ParsePtr s, Trigger *t)
-#else
-    static int ParsePriority(s, t)
-    ParsePtr s;
-    Trigger *t;
-#endif
+static int ParsePriority(ParsePtr s, Trigger *t)
 {
     int p, r;
     char *u;
@@ -928,19 +837,12 @@ PRIVATE int ParsePriority(ParsePtr s, Trigger *t)
 /*  Execute the '-k' command, escaping shell chars in message. */
 /*                                                             */
 /***************************************************************/
-#ifdef HAVE_PROTOS
-PUBLIC int DoMsgCommand(char *cmd, char *msg)
-#else
-    int DoMsgCommand(cmd, msg)
-    char *cmd;
-    char *msg;
-#endif
+int DoMsgCommand(char *cmd, char *msg)
 {
     int r;
     int i, l;
     DynamicBuffer execBuffer;
 
-#ifdef WANT_SHELL_ESCAPING
     DynamicBuffer buf;
     char *s;
 
@@ -949,7 +851,7 @@ PUBLIC int DoMsgCommand(char *cmd, char *msg)
 
     /* Escape shell characters in msg INCLUDING WHITESPACE! */
     for (s=msg; *s; s++) {
-	if (isspace(*s) || strchr(EscapeMe, *s)) {
+	if (isspace(*s) || !strchr(DontEscapeMe, *s)) {
 	    if (DBufPutc(&buf, '\\') != OK) {
 		r = E_NO_MEM;
 		goto finished;
@@ -961,9 +863,6 @@ PUBLIC int DoMsgCommand(char *cmd, char *msg)
 	}
     }
     msg = DBufValue(&buf);
-#else
-    DBufInit(&execBuffer);
-#endif
 
     /* Do "%s" substitution */
     l = strlen(cmd)-1;
@@ -991,9 +890,7 @@ PUBLIC int DoMsgCommand(char *cmd, char *msg)
     system(DBufValue(&execBuffer));
 
 finished:
-#ifdef WANT_SHELL_ESCAPING
     DBufFree(&buf);
-#endif
     DBufFree(&execBuffer);
     return r;
 }
@@ -1006,13 +903,7 @@ finished:
 /*  function.                                                  */
 /*                                                             */
 /***************************************************************/
-#ifdef HAVE_PROTOS
-PRIVATE int ShouldTriggerBasedOnWarn(Trigger *t, int jul)
-#else
-    static int ShouldTriggerBasedOnWarn(t, jul)
-    Trigger *t;
-    int jul;
-#endif
+static int ShouldTriggerBasedOnWarn(Trigger *t, int jul)
 {
     char buffer[VAR_NAME_LEN+32];
     int i;
