@@ -12,20 +12,13 @@
 /***************************************************************/
 
 #include "config.h"
-static char const RCSID[] = "$Id: token.c,v 1.10 2001/11/06 15:51:37 dfs Exp $";
+static char const RCSID[] = "$Id: token.c,v 1.13 2005/11/20 01:26:59 dfs Exp $";
 
 #include <stdio.h>
 #include <string.h>
 #include <ctype.h>
 
-#ifdef HAVE_STDLIB_H
 #include <stdlib.h>
-#endif
-
-#ifdef HAVE_MALLOC_H
-#include <malloc.h>
-#endif
-
 #include "types.h"
 #include "globals.h"
 #include "protos.h"
@@ -137,7 +130,7 @@ Token NonEnglishToks[] = {
 };
 #endif
 
-PRIVATE int TokStrCmp ARGS((const Token *t, const char *s));
+static int TokStrCmp (const Token *t, const char *s);
 
 /***************************************************************/
 /*                                                             */
@@ -147,13 +140,7 @@ PRIVATE int TokStrCmp ARGS((const Token *t, const char *s));
 /*  left square bracket, return a T_Illegal type.              */
 /*                                                             */
 /***************************************************************/
-#ifdef HAVE_PROTOS
-PUBLIC char *FindInitialToken(Token *tok, char *s)
-#else
-char *FindInitialToken(tok, s)
-Token *tok;
-char *s;
-#endif
+char *FindInitialToken(Token *tok, char *s)
 {
     DynamicBuffer buf;
     DBufInit(&buf);
@@ -180,15 +167,9 @@ char *s;
 /*  Given a string, which token is it?                         */
 /*                                                             */
 /***************************************************************/
-#ifdef HAVE_PROTOS
-PUBLIC void FindToken(const char *s, Token *tok)
-#else
-void FindToken(s, tok)
-char *s;
-Token *tok;
-#endif
+void FindToken(const char *s, Token *tok)
 {
-    register int top, bot, mid, r;
+    int top, bot, mid, r, max;
     int l;
 
     tok->type = T_Illegal;
@@ -216,6 +197,7 @@ Token *tok;
     }
     bot = 0;
     top = sizeof(TokArray) / sizeof(TokArray[0]) - 1;
+    max = sizeof(TokArray) / sizeof(TokArray[0]);
 
     while(top >= bot) {
 	mid = (top + bot) / 2;
@@ -227,9 +209,13 @@ Token *tok;
 		return;
 	    } else {
 		while (mid && !TokStrCmp(&TokArray[mid-1],s)) mid--;
-		while (!TokStrCmp(&TokArray[mid], s) && l < TokArray[mid].MinLen)
+		while (mid < max &&
+		       !TokStrCmp(&TokArray[mid], s) &&
+		       l < TokArray[mid].MinLen) {
 		    mid++;
-		if (!TokStrCmp(&TokArray[mid], s)) {
+		}
+		if (mid < max &&
+		    !TokStrCmp(&TokArray[mid], s)) {
 		    tok->type = TokArray[mid].type;
 		    tok->val = TokArray[mid].val;
 		    return;
@@ -268,13 +254,7 @@ Token *tok;
 /*  Rep - *n                                                   */
 /*                                                             */
 /***************************************************************/
-#ifdef HAVE_PROTOS
-PUBLIC void FindNumericToken(const char *s, Token *t)
-#else
-void FindNumericToken(s, t)
-char *s;
-Token *t;
-#endif
+void FindNumericToken(const char *s, Token *t)
 {
     int mult = 1, hour, min;
 
@@ -302,9 +282,13 @@ Token *t;
 	    s++;
 	    hour = t->val;
 	    PARSENUM(min, s);
-	    if (*s || hour > 23 || min > 59) return;  /* Illegal time */
+	    if (*s || min > 59) return;  /* Illegal time */
 	    t->val = hour*60 + min;  /* Convert to minutes past midnight */
-	    t->type = T_Time;
+	    if (hour <= 23) {
+		t->type = T_Time;
+	    } else {
+		t->type = T_LongTime;
+	    }
 	    return;
 	}
 
@@ -353,13 +337,7 @@ Token *t;
 /*  Compare a token to a string.                               */
 /*                                                             */
 /***************************************************************/
-#ifdef HAVE_PROTOS
-PRIVATE int TokStrCmp(const Token *t, const char *s)
-#else
-static int TokStrCmp(t, s)
-Token *t;
-char *s;
-#endif
+static int TokStrCmp(const Token *t, const char *s)
 {
     register int r;
     char *tk = t->name;
