@@ -10,8 +10,9 @@
 /*                                                             */
 /***************************************************************/
 
-/* $Id: types.h,v 1.5 2000/02/18 03:46:12 dfs Exp $ */
+/* $Id: types.h,v 1.7 2005/11/20 01:26:59 dfs Exp $ */
 
+#include <limits.h>
 #include "dynbuf.h"
 
 /* Values */
@@ -28,11 +29,7 @@ typedef struct {
     char *name;
     char prec;
     char type;
-#ifdef HAVE_PROTOS
     int (*func)(void);
-#else
-    int (*func) ();
-#endif
 } Operator;
 
 /* Define the structure of a variable */
@@ -105,7 +102,7 @@ typedef Parser *ParsePtr;  /* Pointer to parser structure */
 #define BEFORE_SKIP 2
 #define AFTER_SKIP 3
 
-#define NO_TIME 1500 /* >1440, ie > than the largest possible legal time */
+#define NO_TIME INT_MAX
 
 #define NO_PRIORITY 5000 /* Default priority is midway between 0 and 9999 */
 
@@ -150,7 +147,8 @@ enum TokTypes
   T_Sched,
   T_Warn,
   T_Tag,
-  T_Duration
+  T_Duration,
+  T_LongTime
 };
 
 /* The structure of a token */
